Crate arweave_rs_validator

Validates all of the Arweave block header fields follow Arweave consensus rules.

Modules

merkle
Validates merkle tree proofs for the Proof of Access chunks in an Arweave block header.

Functions

pre_validate_block
Sequentially performs all of the checks required to validate an Arweave block starting with the simplest (least expensive) checks and finishing with the most involved checks. Note: This excludes the VDF checkpoint validation which is performed separately.